==> jc-1.4.0.tar.gz: java/security/MessageDigestSpi.h <==
// public abstract class java.security.MessageDigestSpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7d8127440fb7dad2 java_security_MessageDigestSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_MessageDigestSpi_H_
#define _JC_java_security_MessageDigestSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_security_MessageDigestSpi$sub_refs	_jc_java_security_MessageDigestSpi$sub_refs;
typedef struct _jc_java_security_MessageDigestSpi$sub_nonrefs	_jc_java_security_MessageDigestSpi$sub_nonrefs;
typedef struct _jc_java_security_MessageDigestSpi$refs	_jc_java_security_MessageDigestSpi$refs;
typedef struct _jc_java_security_MessageDigestSpi$nonrefs	_jc_java_security_MessageDigestSpi$nonrefs;
typedef struct _jc_java_security_MessageDigestSpi$object	_jc_java_security_MessageDigestSpi$object;

typedef const struct _jc_java_security_MessageDigestSpi$vmethods	_jc_java_security_MessageDigestSpi$vmethods;
typedef const struct _jc_java_security_MessageDigestSpi$vtable	_jc_java_security_MessageDigestSpi$vtable;
typedef const struct _jc_java_security_MessageDigestSpi$vtype	_jc_java_security_MessageDigestSpi$vtype;

// Constructors
extern void _jc_java_security_MessageDigestSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_MessageDigestSpi$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *);
extern _jc_byte_array *_jc_java_security_MessageDigestSpi$method$engineDigest$af4966fb4f066ce0(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *);
extern jint _jc_java_security_MessageDigestSpi$method$engineDigest$f590996905113538(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *, struct _jc_byte_array *, jint, jint);
extern jint _jc_java_security_MessageDigestSpi$method$engineGetDigestLength$74fcf1ae739bccab(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *);
extern void _jc_java_security_MessageDigestSpi$method$engineReset$216e0febda0be220(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *);
extern void _jc_java_security_MessageDigestSpi$method$engineUpdate$807e0421d3c3a314(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *, jbyte);
extern void _jc_java_security_MessageDigestSpi$method$engineUpdate$d2f85b5d32010900(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_security_MessageDigestSpi$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_security_MessageDigestSpi$method_info$engineDigest$af4966fb4f066ce0;
extern _jc_method _jc_java_security_MessageDigestSpi$method_info$engineDigest$f590996905113538;
extern _jc_method _jc_java_security_MessageDigestSpi$method_info$engineGetDigestLength$74fcf1ae739bccab;
extern _jc_method _jc_java_security_MessageDigestSpi$method_info$engineReset$216e0febda0be220;
extern _jc_method _jc_java_security_MessageDigestSpi$method_info$engineUpdate$807e0421d3c3a314;
extern _jc_method _jc_java_security_MessageDigestSpi$method_info$engineUpdate$d2f85b5d32010900;

// Virtual methods structure
struct _jc_java_security_MessageDigestSpi$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *);
	_jc_byte_array	*(*engineDigest$af4966fb4f066ce0)(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *);
	jint	(*engineDigest$f590996905113538)(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *, struct _jc_byte_array *, jint, jint);
	jint	(*engineGetDigestLength$74fcf1ae739bccab)(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *);
	void	(*engineReset$216e0febda0be220)(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *);
	void	(*engineUpdate$807e0421d3c3a314)(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *, jbyte);
	void	(*engineUpdate$d2f85b5d32010900)(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_java_security_MessageDigestSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_MessageDigestSpi$vmethods	java_security_MessageDigestSpi;
};

// Vtype
struct _jc_java_security_MessageDigestSpi$vtype {
	_jc_type			type;
	_jc_java_security_MessageDigestSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_MessageDigestSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_MessageDigestSpi$refs {
    _jc_java_security_MessageDigestSpi$sub_refs	java_security_MessageDigestSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_MessageDigestSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_MessageDigestSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_MessageDigestSpi$sub_nonrefs	java_security_MessageDigestSpi;
};

// Object instance structure
struct _jc_java_security_MessageDigestSpi$object {
	_jc_java_security_MessageDigestSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_MessageDigestSpi$vtype	*vtype;
	_jc_java_security_MessageDigestSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_MessageDigestSpi$vtype _jc_java_security_MessageDigestSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_MessageDigestSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_MessageDigestSpi$class_object;

#endif	/* _JC_java_security_MessageDigestSpi_H_ */

==> jc-1.4.6.tar.gz: java/security/MessageDigestSpi.h <==
// public abstract class java.security.MessageDigestSpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7d8127440fb7dad2 java_security_MessageDigestSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_MessageDigestSpi_H_
#define _JC_java_security_MessageDigestSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_security_MessageDigestSpi$sub_refs	_jc_java_security_MessageDigestSpi$sub_refs;
typedef struct _jc_java_security_MessageDigestSpi$sub_nonrefs	_jc_java_security_MessageDigestSpi$sub_nonrefs;
typedef struct _jc_java_security_MessageDigestSpi$refs	_jc_java_security_MessageDigestSpi$refs;
typedef struct _jc_java_security_MessageDigestSpi$nonrefs	_jc_java_security_MessageDigestSpi$nonrefs;
typedef struct _jc_java_security_MessageDigestSpi$object	_jc_java_security_MessageDigestSpi$object;

typedef const struct _jc_java_security_MessageDigestSpi$vmethods	_jc_java_security_MessageDigestSpi$vmethods;
typedef const struct _jc_java_security_MessageDigestSpi$vtable	_jc_java_security_MessageDigestSpi$vtable;
typedef const struct _jc_java_security_MessageDigestSpi$vtype	_jc_java_security_MessageDigestSpi$vtype;

// Constructors
extern void _jc_java_security_MessageDigestSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_MessageDigestSpi$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_java_security_MessageDigestSpi$method$engineDigest$af4966fb4f066ce0(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *) _JC_JCNI_ATTR;
extern jint _jc_java_security_MessageDigestSpi$method$engineDigest$f590996905113538(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern jint _jc_java_security_MessageDigestSpi$method$engineGetDigestLength$74fcf1ae739bccab(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_MessageDigestSpi$method$engineReset$216e0febda0be220(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_MessageDigestSpi$method$engineUpdate$807e0421d3c3a314(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *, jbyte) _JC_JCNI_ATTR;
extern void _jc_java_security_MessageDigestSpi$method$engineUpdate$d2f85b5d32010900(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_MessageDigestSpi$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_security_MessageDigestSpi$method_info$engineDigest$af4966fb4f066ce0;
extern _jc_method _jc_java_security_MessageDigestSpi$method_info$engineDigest$f590996905113538;
extern _jc_method _jc_java_security_MessageDigestSpi$method_info$engineGetDigestLength$74fcf1ae739bccab;
extern _jc_method _jc_java_security_MessageDigestSpi$method_info$engineReset$216e0febda0be220;
extern _jc_method _jc_java_security_MessageDigestSpi$method_info$engineUpdate$807e0421d3c3a314;
extern _jc_method _jc_java_security_MessageDigestSpi$method_info$engineUpdate$d2f85b5d32010900;

// Virtual methods structure
struct _jc_java_security_MessageDigestSpi$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*engineDigest$af4966fb4f066ce0)(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *) _JC_JCNI_ATTR;
	jint	(*engineDigest$f590996905113538)(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	jint	(*engineGetDigestLength$74fcf1ae739bccab)(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *) _JC_JCNI_ATTR;
	void	(*engineReset$216e0febda0be220)(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *) _JC_JCNI_ATTR;
	void	(*engineUpdate$807e0421d3c3a314)(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *, jbyte) _JC_JCNI_ATTR;
	void	(*engineUpdate$d2f85b5d32010900)(_jc_env *, struct _jc_java_security_MessageDigestSpi$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_MessageDigestSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_MessageDigestSpi$vmethods	java_security_MessageDigestSpi;
};

// Vtype
struct _jc_java_security_MessageDigestSpi$vtype {
	_jc_type			type;
	_jc_java_security_MessageDigestSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_MessageDigestSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_MessageDigestSpi$refs {
    _jc_java_security_MessageDigestSpi$sub_refs	java_security_MessageDigestSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_MessageDigestSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_MessageDigestSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_MessageDigestSpi$sub_nonrefs	java_security_MessageDigestSpi;
};

// Object instance structure
struct _jc_java_security_MessageDigestSpi$object {
	_jc_java_security_MessageDigestSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_MessageDigestSpi$vtype	*vtype;
	_jc_java_security_MessageDigestSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_MessageDigestSpi$vtype _jc_java_security_MessageDigestSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_MessageDigestSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_MessageDigestSpi$class_object;

#endif	/* _JC_java_security_MessageDigestSpi_H_ */
